*********************************************************************************
** This code generates Appendix Figure 14, which reports the share of 		   **
** respondents who rank the following as the most important policy priority    **
*********************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


****************************************************************
** Compute conditional shares and create the figure by income **
****************************************************************

{
preserve

*Note: keep only respondents who do not see the treatment video on the trade-offs between inflation and unemployment.

keep if treatment==0

*Note: respondents are presented economic issues (inflation, financial stability, national defense, economic growth, low unemployment) and social issues (inflation healthcare, education, civil rights, abortion, gun rights). Variables are dummies equal to 1 when the respondent ranks the economic/social issue considered first among all the issues presented.

global social  dummy_gun_first_sc dummy_abortion_first_sc dummy_civil_first_sc dummy_educ_first_sc dummy_health_first_sc dummy_inf_first_sc
global economic  dummy_lowu_first_ec dummy_growth_first_ec dummy_defense_first_ec dummy_finstab_first_ec dummy_inf_first_ec


* Compute and store conditional means and standard errors by income.

global j=1

foreach var_selec of varlist $social{
	sum `var_selec' if incomegroup_agg==1
	scalar    mechanisms_low_${j}=r(mean)*100 
	scalar se_mechanisms_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    mechanisms_${j}=r(mean)*100 
	scalar se_mechanisms_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if incomegroup_agg==3
	scalar    mechanisms_high_${j}=r(mean)*100 
	scalar se_mechanisms_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $economic{
	sum `var_selec' if incomegroup_agg==1
	scalar    signal_low_${j}=r(mean)*100 
	scalar se_signal_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    signal_${j}=r(mean)*100 
	scalar se_signal_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if incomegroup_agg==3
	scalar    signal_high_${j}=r(mean)*100 
	scalar se_signal_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}


clear
set obs 48
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in mechanisms mechanisms_low mechanisms_high signal signal_low signal_high  {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17 21 {
replace mechanisms_low = mechanisms_low_`x' if n == `x'
replace min_mechanisms_low = mechanisms_low_`x'  - 1.965 * se_mechanisms_low_`x'  if n == `x'
replace max_mechanisms_low = mechanisms_low_`x'  + 1.965 * se_mechanisms_low_`x'  if n == `x'
scalar up_`x'=mechanisms_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18 22 {
replace mechanisms = mechanisms_`x' if n == `x'
replace min_mechanisms = mechanisms_`x'  - 1.965 * se_mechanisms_`x'  if n == `x'
replace max_mechanisms = mechanisms_`x'  + 1.965 * se_mechanisms_`x'  if n == `x'
scalar up_`x'=mechanisms_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 23 {
replace mechanisms_high = mechanisms_high_`x' if n == `x'
replace min_mechanisms_high = mechanisms_high_`x'  - 1.965 * se_mechanisms_high_`x'  if n == `x'
replace max_mechanisms_high = mechanisms_high_`x'  + 1.965 * se_mechanisms_high_`x'  if n == `x'
scalar up_`x'=mechanisms_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in  30 34 38 42 46 {
replace signal_low = signal_low_`x' if n == `x'
replace min_signal_low = signal_low_`x'  - 1.965 * se_signal_low_`x'  if n == `x'
replace max_signal_low = signal_low_`x'  + 1.965 * se_signal_low_`x'  if n == `x'
scalar up_`x'=signal_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in   31 35 39 43 47 {
replace signal = signal_`x' if n == `x'
replace min_signal = signal_`x'  - 1.965 * se_signal_`x'  if n == `x'
replace max_signal = signal_`x'  + 1.965 * se_signal_`x'  if n == `x'
scalar up_`x'=signal_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in  32 36 40 44 48{
replace signal_high = signal_high_`x' if n == `x'
replace min_signal_high = signal_high_`x'  - 1.965 * se_signal_high_`x'  if n == `x'
replace max_signal_high = signal_high_`x'  + 1.965 * se_signal_high_`x'  if n == `x'
scalar up_`x'=signal_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp=0.5+n*0.25 if n<24
replace temp=1.25+0.25*n if temp==.



* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter temp mechanisms_low ,  color(orange) msymbol(O) ) (rcap min_mechanisms_low max_mechanisms_low temp, horizontal color(orange)  )      (scatter temp mechanisms_high ,  color("17 119 51") msymbol(V) ) (rcap min_mechanisms_high max_mechanisms_high temp, horizontal color("17 119 51") )    ///
   (scatter temp signal_low ,  color(orange) msymbol(O) ) (rcap min_signal_low max_signal_low temp, horizontal color(orange) )  (scatter temp signal_high ,  color("17 119 51") msymbol(V) ) (rcap min_signal_high max_signal_high temp,  horizontal color("17 119 51"))  , ///
			 legend(order(1 3) lab(1 "{bf:Income <$40k}") lab(3 "{bf:Income >$125k}")  size(large) position(6) cols(1)  symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center))  xlabel(0(10)60, labsize(medlarge) ) ylabel(1 `" "Gun rights" "' 2  `" "Abortion" "' 3 `" "Civil rights" "' 4 `" "Education" "' 5 `" "Healthcare" "' 6 `" "Inflation" "' 7.5  `" "{bf:Social issues}" "' 9 `" "Low unemployment" "'  10 `" "Economic growth" "' 11 `" "National defense" "' 12 `" "Financial stability" "'  13  `" "Inflation" "'  14.5  `" "{bf:Economic issues}" "'  , labsize(vlarge) noticks nogrid)  xtitle(" " , size(huge)) ytitle("")   yline(7.5 )  yline(1.5 2.5 3.5 4.5 5.5 9.5 10.5 11.5 12.5, lwidth(vthin) lcolor(gray%50)) xsize(3) ysize(4)

			 resize, xsize(15cm) ysize(20cm)

graph export "$appendix_figures/figa14_1.png", as(png) width(2000) height(2600) replace

restore


}


****************************************************************
** Compute conditional shares and create the figure by age    **
****************************************************************

{
preserve

*Note: keep only respondents who do not see the treatment video on the trade-offs between inflation and unemployment.

keep if treatment==0

*Note: respondents are presented economic issues (inflation, financial stability, national defense, economic growth, low unemployment) and social issues (inflation healthcare, education, civil rights, abortion, gun rights). Variables are dummies equal to 1 when the respondent ranks the economic/social issue considered first among all the issues presented.

global social  dummy_gun_first_sc dummy_abortion_first_sc dummy_civil_first_sc dummy_educ_first_sc dummy_health_first_sc dummy_inf_first_sc
global economic  dummy_lowu_first_ec dummy_growth_first_ec dummy_defense_first_ec dummy_finstab_first_ec dummy_inf_first_ec


* Compute and store conditional means and standard errors by age.

global j=1

foreach var_selec of varlist $social{
	sum `var_selec' if agegroup_agg==1
	scalar    mechanisms_low_${j}=r(mean)*100 
	scalar se_mechanisms_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    mechanisms_${j}=r(mean)*100 
	scalar se_mechanisms_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if agegroup_agg==3
	scalar    mechanisms_high_${j}=r(mean)*100 
	scalar se_mechanisms_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $economic{
	sum `var_selec' if agegroup_agg==1
	scalar    signal_low_${j}=r(mean)*100 
	scalar se_signal_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    signal_${j}=r(mean)*100 
	scalar se_signal_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if agegroup_agg==3
	scalar    signal_high_${j}=r(mean)*100 
	scalar se_signal_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}


clear
set obs 48
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in mechanisms mechanisms_low mechanisms_high signal signal_low signal_high  {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17 21 {
replace mechanisms_low = mechanisms_low_`x' if n == `x'
replace min_mechanisms_low = mechanisms_low_`x'  - 1.965 * se_mechanisms_low_`x'  if n == `x'
replace max_mechanisms_low = mechanisms_low_`x'  + 1.965 * se_mechanisms_low_`x'  if n == `x'
scalar up_`x'=mechanisms_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 10 14 18 22 {
replace mechanisms = mechanisms_`x' if n == `x'
replace min_mechanisms = mechanisms_`x'  - 1.965 * se_mechanisms_`x'  if n == `x'
replace max_mechanisms = mechanisms_`x'  + 1.965 * se_mechanisms_`x'  if n == `x'
scalar up_`x'=mechanisms_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 11 15 19 23 {
replace mechanisms_high = mechanisms_high_`x' if n == `x'
replace min_mechanisms_high = mechanisms_high_`x'  - 1.965 * se_mechanisms_high_`x'  if n == `x'
replace max_mechanisms_high = mechanisms_high_`x'  + 1.965 * se_mechanisms_high_`x'  if n == `x'
scalar up_`x'=mechanisms_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in  30 34 38 42 46 {
replace signal_low = signal_low_`x' if n == `x'
replace min_signal_low = signal_low_`x'  - 1.965 * se_signal_low_`x'  if n == `x'
replace max_signal_low = signal_low_`x'  + 1.965 * se_signal_low_`x'  if n == `x'
scalar up_`x'=signal_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in   31 35 39 43 47 {
replace signal = signal_`x' if n == `x'
replace min_signal = signal_`x'  - 1.965 * se_signal_`x'  if n == `x'
replace max_signal = signal_`x'  + 1.965 * se_signal_`x'  if n == `x'
scalar up_`x'=signal_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 32 36 40 44 48{
replace signal_high = signal_high_`x' if n == `x'
replace min_signal_high = signal_high_`x'  - 1.965 * se_signal_high_`x'  if n == `x'
replace max_signal_high = signal_high_`x'  + 1.965 * se_signal_high_`x'  if n == `x'
scalar up_`x'=signal_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp=0.5+n*0.25 if n<24
replace temp=1.25+0.25*n if temp==.



* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter temp mechanisms_low ,  color(black) msymbol(T) ) (rcap min_mechanisms_low max_mechanisms_low temp, horizontal color(black)  )    (scatter temp mechanisms ,  color(pink) msymbol(S) ) (rcap min_mechanisms max_mechanisms temp, horizontal color(pink)  )    (scatter temp mechanisms_high ,  color(purple) msymbol(a) ) (rcap min_mechanisms_high max_mechanisms_high temp, horizontal color(purple) )    ///
   (scatter temp signal_low ,  color(black) msymbol(T) ) (rcap min_signal_low max_signal_low temp, horizontal color(black) )  (scatter temp signal ,  color(pink) msymbol(S) ) (rcap min_signal max_signal temp, horizontal color(pink) )  (scatter temp signal_high ,  color(purple) msymbol(a)) (rcap min_signal_high max_signal_high temp,  horizontal color(purple))  , ///
			 legend(order(1 3 5) lab(1 "{bf:18-29 years}") lab(3 "{bf:30-49 years}") lab(5 "{bf:50-69 years}")   position(6) cols(2) size(medlarge)  symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center)) ///
			 xlabel(0(10)60, labsize(medlarge) ) ylabel(1 `" "Gun rights" "' 2  `" "Abortion" "' 3 `" "Civil rights" "' 4 `" "Education" "' 5 `" "Healthcare" "' 6 `" "Inflation" "' 7.5  `" "{bf:Social issues}" "' 9 `" "Low unemployment" "'  10 `" "Economic growth" "' 11 `" "National defense" "' 12 `" "Financial stability" "'  13  `" "Inflation" "'  14.5  `" "{bf:Economic issues}" "'  , labsize(vlarge) noticks nogrid)  xtitle(" " , size(huge)) ytitle("")   yline(7.5 )  yline(1.5 2.5 3.5 4.5 5.5 9.5 10.5 11.5 12.5, lwidth(vthin) lcolor(gray%50)) xsize(3) ysize(4)

			 resize, xsize(15cm) ysize(20cm)

graph export "$appendix_figures/figa14_2.png", as(png) width(2000) height(2600) replace

restore


}
