**************************************************************************************
** This code generates the Appendix Figure 5, which reports the share of respondents**
** indicating a specific cause as one of the two important causes of inflation,     ** 
** dividing the sample by income and by age.										**
**************************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


****************************************************************
** Compute conditional shares and create the figure by income **
****************************************************************

{
preserve

* Note: these variables are indicators taking value 1 when the respondent chose this cause as one of the two most important causes of inflation

global consumer cause_gvt cause_fed cause_labor cause_politics cause_hh cause_firms   cause_costs

* Compute and store conditional means and standard errors for each cause for respondents with total household income less than $40k, respondents with total household income more than $125k and full sample.

global j=1

foreach var_selec of varlist $consumer{
	sum `var_selec' if incomegroup_agg==1
	scalar    cons_impact_low_${j}=r(mean)*100 
	scalar se_cons_impact_low_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if incomegroup_agg==2
	scalar    cons_impact_${j}=r(mean)*100 
	scalar se_cons_impact_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    cons_impact_high_${j}=r(mean)*100 
	scalar se_cons_impact_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}


clear
set obs 27
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in cons_impact cons_impact_low cons_impact_high{
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17 21 25  {
replace cons_impact_low = cons_impact_low_`x' if n == `x'
replace min_cons_impact_low = cons_impact_low_`x'  - 1.965 * se_cons_impact_low_`x'  if n == `x'
replace max_cons_impact_low = cons_impact_low_`x'  + 1.965 * se_cons_impact_low_`x'  if n == `x'
scalar up_`x'=cons_impact_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+10
}

foreach x in 2 6 10 14 18 22 26  {
replace cons_impact = cons_impact_`x' if n == `x'
replace min_cons_impact = cons_impact_`x'  - 1.965 * se_cons_impact_`x'  if n == `x'
replace max_cons_impact = cons_impact_`x'  + 1.965 * se_cons_impact_`x'  if n == `x'
scalar up_`x'=cons_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+10
}

foreach x in 3 7 11 15 19 23 27  {
replace cons_impact_high = cons_impact_high_`x' if n == `x'
replace min_cons_impact_high = cons_impact_high_`x'  - 1.965 * se_cons_impact_high_`x'  if n == `x'
replace max_cons_impact_high = cons_impact_high_`x'  + 1.965 * se_cons_impact_high_`x'  if n == `x'
scalar up_`x'=cons_impact_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+10
}


* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter n cons_impact_low ,  color(orange) msymbol(O) ) (rcap min_cons_impact_low max_cons_impact_low n, horizontal color(orange))(scatter n cons_impact_high ,  color("17 119 51") msymbol(V)) (rcap min_cons_impact_high max_cons_impact_high n, horizontal color("17 119 51")) , ///
			 legend(order(1 3) lab(1 "{bf:Income <$40k}") lab(3 "{bf:Income >$125k}")  size(medium) position(6) cols(2)  symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center)) xlabel(0(20)100,  labsize(medium)) ylabel(  2 `" "Government spending," "debt, and taxation" "' 6 `" "Action by the" "Federal Reserve" "' 10 `" "Changes in the" "labor market" "' 14 `" "Politicians and" "political interests" "' 18 `" "Households spending" "more" "' 22 `" "Actions by firms" "and businesses" "' 26 `""Increases in the costs" "of production" "'  , labsize(medium) noticks nogrid) xtitle("") ytitle("") name(gr1, replace)
	
	graph export $appendix_figures/figa5_1.png,  as(png) replace
restore

}




*************************************************************
** Compute conditional shares and create the figure by age **
*************************************************************


{
preserve

global consumer   cause_gvt cause_fed cause_labor cause_politics cause_hh cause_firms   cause_costs


* Compute and store conditional means and standard errors for each cause for respondents with age 18-29, 30-49, and 50-69.

global j=1

foreach var_selec of varlist $consumer{
	sum `var_selec' if agegroup_agg==1
	scalar    cons_impact_low_${j}=r(mean)*100 
	scalar se_cons_impact_low_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    cons_impact_${j}=r(mean)*100 
	scalar se_cons_impact_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    cons_impact_high_${j}=r(mean)*100 
	scalar se_cons_impact_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}


clear
set obs 27
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in cons_impact cons_impact_low cons_impact_high{
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 9 13 17 21 25  {
replace cons_impact_low = cons_impact_low_`x' if n == `x'
replace min_cons_impact_low = cons_impact_low_`x'  - 1.965 * se_cons_impact_low_`x'  if n == `x'
replace max_cons_impact_low = cons_impact_low_`x'  + 1.965 * se_cons_impact_low_`x'  if n == `x'
scalar up_`x'=cons_impact_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+10
}

foreach x in 2 6 10 14 18 22 26  {
replace cons_impact = cons_impact_`x' if n == `x'
replace min_cons_impact = cons_impact_`x'  - 1.965 * se_cons_impact_`x'  if n == `x'
replace max_cons_impact = cons_impact_`x'  + 1.965 * se_cons_impact_`x'  if n == `x'
scalar up_`x'=cons_impact_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+10
}

foreach x in 3 7 11 15 19 23 27  {
replace cons_impact_high = cons_impact_high_`x' if n == `x'
replace min_cons_impact_high = cons_impact_high_`x'  - 1.965 * se_cons_impact_high_`x'  if n == `x'
replace max_cons_impact_high = cons_impact_high_`x'  + 1.965 * se_cons_impact_high_`x'  if n == `x'
scalar up_`x'=cons_impact_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+10
}




* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway (scatter n cons_impact_low ,  color(black) msymbol(T) ) (rcap min_cons_impact_low max_cons_impact_low n, horizontal color(black))(scatter n cons_impact ,  color(pink) msymbol(S)) (rcap min_cons_impact max_cons_impact n, horizontal color(pink)) (scatter n cons_impact_high ,  color(purple) msymbol(a) ) (rcap min_cons_impact_high max_cons_impact_high n, horizontal color(purple)) , ///
			 legend(order(1 3 5) lab(1 "{bf:18-29 years}") lab(3 "{bf:30-49 years}") lab(5 "{bf:50-69 years}")  size(medium) position(6) cols(2)  symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center)) xlabel(0(20)100, labsize(medium)) ylabel(  2 `" "Government spending," "debt, and taxation" "' 6 `" "Action by the" "Federal Reserve" "' 10 `" "Changes in the" "labor market" "' 14 `" "Politicians and" "political interests" "' 18 `" "Households spending" "more" "' 22 `" "Actions by firms" "and businesses" "' 26 `""Increases in the costs" "of production" "' , labsize(medium) noticks nogrid)  xtitle("") ytitle("") name(gr3, replace)
			 	
	graph export $appendix_figures/figa5_2.png,  as(png) replace
restore

}

