******************************************************************************
** This code generates Appendix Figure 6, which reports the negative        ** 
** distributional impacts of inflation on groups of the population, 		**
** dividing the sample by income and age.									**
******************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*** set general style

grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"

****************************************************************
** Compute conditional shares and create the figure by income **
****************************************************************

{
preserve

* Note: The variables used in this code are indicators taking value 1 when the respondent reports that a group of the population has lost a lot or somewhat because of inflation (e.g., variable dummy_distr_highincome considers measures the share of respondents who believe that high income people have been impacted negatively by inflation).

global income dummy_distr_highincome dummy_distr_midincome dummy_distr_lowincome
global age dummy_distr_young dummy_distr_midage dummy_distr_old
global employment dummy_distr_unemp dummy_distr_emp dummy_distr_retire
global savings dummy_distr_cash dummy_distr_finassets dummy_distr_nosave
global debt dummy_distr_ccdebt dummy_distr_fixrate dummy_distr_flexrate dummy_distr_nodebt
global firms dummy_distr_smallfirms dummy_distr_bigfirms


* Compute and store conditional means and standard errors for respondents with total household income less than $40k, respondents with total household income more than $125k and full sample.

global j=1

foreach var_selec of varlist $firms{
	sum `var_selec' if incomegroup_agg==1
	scalar    firms_low_${j}=r(mean)*100 
	scalar se_firms_low_${j}=(r(sd)/sqrt(r(N)))*100
	global  j=$j +1
	sum `var_selec' if incomegroup_agg==2
	scalar    firms_${j}=r(mean)*100 
	scalar se_firms_${j}=(r(sd)/sqrt(r(N)))*100
	global  j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    firms_high_${j}=r(mean)*100 
	scalar se_firms_high_${j}=(r(sd)/sqrt(r(N)))*100

global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $debt{
	sum `var_selec' if incomegroup_agg==1
	scalar    debt_low_${j}=r(mean)*100 
	scalar se_debt_low_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec'  if incomegroup_agg==2
	scalar    debt_${j}=r(mean)*100 
	scalar se_debt_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    debt_high_${j}=r(mean)*100 
	scalar se_debt_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $savings {
	sum `var_selec' if incomegroup_agg==1
	scalar    savings_low_${j}=r(mean)*100 
	scalar se_savings_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'  if incomegroup_agg==2
	scalar    savings_${j}=r(mean)*100 
	scalar se_savings_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    savings_high_${j}=r(mean)*100 
	scalar se_savings_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $employment{
	sum `var_selec' if incomegroup_agg==1
	scalar    employment_low_${j}=r(mean)*100 
	scalar se_employment_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'  if incomegroup_agg==2
	scalar    employment_${j}=r(mean)*100 
	scalar se_employment_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if incomegroup_agg==3
	scalar    employment_high_${j}=r(mean)*100 
	scalar se_employment_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $age{
		sum `var_selec' if incomegroup_agg==1
	scalar    age_low_${j}=r(mean)*100 
	scalar se_age_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'  if incomegroup_agg==2
	scalar    age_${j}=r(mean)*100 
	scalar se_age_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if incomegroup_agg==3
	scalar    age_high_${j}=r(mean)*100 
	scalar se_age_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $income{
	sum `var_selec' if incomegroup_agg==1
	scalar    income_low_${j}=r(mean)*100 
	scalar se_income_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec'
	scalar    income_${j}=r(mean)*100 
	scalar se_income_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if incomegroup_agg==3
	scalar    income_high_${j}=r(mean)*100 
	scalar se_income_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}



clear
set obs 96
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in firms firms_low firms_high debt debt_low debt_high savings savings_low savings_high employment employment_low employment_high age age_low age_high income income_low income_high {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 {
replace firms_low = firms_low_`x' if n == `x'
replace min_firms_low = firms_low_`x'  - 1.965 * se_firms_low_`x'  if n == `x'
replace max_firms_low = firms_low_`x'  + 1.965 * se_firms_low_`x'  if n == `x'
scalar up_`x'=firms_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 {
replace firms = firms_`x' if n == `x'
replace min_firms = firms_`x'  - 1.965 * se_firms_`x'  if n == `x'
replace max_firms = firms_`x'  + 1.965 * se_firms_`x'  if n == `x'
scalar up_`x'=firms_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 {
replace firms_high = firms_high_`x' if n == `x'
replace min_firms_high = firms_high_`x'  - 1.965 * se_firms_high_`x'  if n == `x'
replace max_firms_high = firms_high_`x'  + 1.965 * se_firms_high_`x'  if n == `x'
scalar up_`x'=firms_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


foreach x in 14 18 22 26 {
replace debt_low = debt_low_`x' if n == `x'
replace min_debt_low = debt_low_`x'  - 1.965 * se_debt_low_`x'  if n == `x'
replace max_debt_low = debt_low_`x'  + 1.965 * se_debt_low_`x'  if n == `x'
scalar up_`x'=debt_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 15 19 23 27 {
replace debt = debt_`x' if n == `x'
replace min_debt = debt_`x'  - 1.965 * se_debt_`x'  if n == `x'
replace max_debt = debt_`x'  + 1.965 * se_debt_`x'  if n == `x'
scalar up_`x'=debt_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 16 20 24 28 {
replace debt_high = debt_high_`x' if n == `x'
replace min_debt_high = debt_high_`x'  - 1.965 * se_debt_high_`x'  if n == `x'
replace max_debt_high = debt_high_`x'  + 1.965 * se_debt_high_`x'  if n == `x'
scalar up_`x'=debt_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}



foreach x in 35 39 43 {
replace savings_low = savings_low_`x' if n == `x'
replace min_savings_low = savings_low_`x'  - 1.965 * se_savings_low_`x'  if n == `x'
replace max_savings_low = savings_low_`x'  + 1.965 * se_savings_low_`x'  if n == `x'
scalar up_`x'=savings_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 36 40 44 {
replace savings = savings_`x' if n == `x'
replace min_savings = savings_`x'  - 1.965 * se_savings_`x'  if n == `x'
replace max_savings = savings_`x'  + 1.965 * se_savings_`x'  if n == `x'
scalar up_`x'=savings_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 37 41 45 {
replace savings_high = savings_high_`x' if n == `x'
replace min_savings_high = savings_high_`x'  - 1.965 * se_savings_high_`x'  if n == `x'
replace max_savings_high = savings_high_`x'  + 1.965 * se_savings_high_`x'  if n == `x'
scalar up_`x'=savings_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 52 56 60 {
replace employment_low = employment_low_`x' if n == `x'
replace min_employment_low = employment_low_`x'  - 1.965 * se_employment_low_`x'  if n == `x'
replace max_employment_low = employment_low_`x'  + 1.965 * se_employment_low_`x'  if n == `x'
scalar up_`x'=employment_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 53 57 61 {
replace employment = employment_`x' if n == `x'
replace min_employment = employment_`x'  - 1.965 * se_employment_`x'  if n == `x'
replace max_employment = employment_`x'  + 1.965 * se_employment_`x'  if n == `x'
scalar up_`x'=employment_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 54 58 62 {
replace employment_high = employment_high_`x' if n == `x'
replace min_employment_high = employment_high_`x'  - 1.965 * se_employment_high_`x'  if n == `x'
replace max_employment_high = employment_high_`x'  + 1.965 * se_employment_high_`x'  if n == `x'
scalar up_`x'=employment_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 69 73 77 {
replace age_low = age_low_`x' if n == `x'
replace min_age_low = age_low_`x'  - 1.965 * se_age_low_`x'  if n == `x'
replace max_age_low = age_low_`x'  + 1.965 * se_age_low_`x'  if n == `x'
scalar up_`x'=age_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 70 74 78 {
replace age = age_`x' if n == `x'
replace min_age = age_`x'  - 1.965 * se_age_`x'  if n == `x'
replace max_age = age_`x'  + 1.965 * se_age_`x'  if n == `x'
scalar up_`x'=age_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 71 75 79 {
replace age_high = age_high_`x' if n == `x'
replace min_age_high = age_high_`x'  - 1.965 * se_age_high_`x'  if n == `x'
replace max_age_high = age_high_`x'  + 1.965 * se_age_high_`x'  if n == `x'
scalar up_`x'=age_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 86 90 94 {
replace income_low = income_low_`x' if n == `x'
replace min_income_low = income_low_`x'  - 1.965 * se_income_low_`x'  if n == `x'
replace max_income_low = income_low_`x'  + 1.965 * se_income_low_`x'  if n == `x'
scalar up_`x'=income_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}
	
foreach x in 87 91 95 {
replace income = income_`x' if n == `x'
replace min_income = income_`x'  - 1.965 * se_income_`x'  if n == `x'
replace max_income = income_`x'  + 1.965 * se_income_`x'  if n == `x'
scalar up_`x'=income_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 88 92 96 {
replace income_high = income_high_`x' if n == `x'
replace min_income_high = income_high_`x'  - 1.965 * se_income_high_`x'  if n == `x'
replace max_income_high = income_high_`x'  + 1.965 * se_income_high_`x'  if n == `x'
scalar up_`x'=income_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp = 0.5+n*0.25 if n<8
replace temp = 1.25 +n*0.25 if n<29 & temp==.
replace temp=2 +n*0.25 if n<46 & temp==.
replace temp=2.75 +n*0.25 if n<63 & temp==.
replace temp=3.5 + n*0.25 if n<80 & temp==.
replace temp=4.25 + n*0.25 if temp==.


*set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway ( scatter temp firms_low , msymbol(O) color(orange)) (rcap min_firms_low max_firms_low temp,  lwidth( thin) horizontal color(orange))    ( scatter temp firms_high , msymbol(V) color("17 119 51")  ) (rcap min_firms_high max_firms_high temp,  lwidth( thin) color("17 119 51") horizontal)  ///
   ( scatter temp debt_low , msymbol(O) color(orange)  ) (rcap min_debt_low max_debt_low temp,  horizontal  color(orange) lwidth( thin))    ( scatter temp debt_high ,  msymbol(V)  color("17 119 51")  ) (rcap min_debt_high max_debt_high temp,  horizontal color("17 119 51") lwidth( thin))    ///
    ( scatter temp savings_low , msymbol(O) color(orange)  ) (rcap min_savings_low max_savings_low temp, horizontal lwidth( thin)  color(orange))  ( scatter temp savings_high ,  msymbol(V)  color("17 119 51")  ) (rcap min_savings_high max_savings_high temp,  lwidth( thin) horizontal color("17 119 51")) ///
     ( scatter temp employment_low , msymbol(O) color(orange)  ) (rcap min_employment_low max_employment_low temp,  horizontal lwidth( thin) color(orange))  ( scatter temp employment_high ,  msymbol(V) color("17 119 51")  ) (rcap min_employment_high max_employment_high temp,   lwidth( thin) horizontal color("17 119 51")) ///
	  ( scatter temp age_low , msymbol(O) color(orange)  ) (rcap min_age_low max_age_low temp,  horizontal  color(orange) lwidth( thin))  ( scatter temp age_high ,  msymbol(V)  color("17 119 51")  ) (rcap min_age_high max_age_high temp,  horizontal lwidth( thin) color("17 119 51")) ///
	  ( scatter temp income_low , msymbol(O) color(orange)  ) (rcap min_income_low max_income_low temp,  horizontal lwidth( thin)  color(orange)) ( scatter temp income_high ,  msymbol(V)  color("17 119 51")  ) (rcap min_income_high max_income_high temp,  lwidth( thin) horizontal  color("17 119 51")), ///
			 legend(order(1 3) lab(1 "{bf:Income <$40k}") lab(3 "{bf:Income >$125k}")  size(standard) position(6) cols(1) symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center)) xlabel(0(20)100, labsize(standard) ) ylabel(1 `" "Small companies" "'  2  `" "Large companies" "' 3.5 `" "{bf:By firm type}" "' 5 `" "Credit card debt" "' 6 `" "Fixed r mortgage" "' 7 `" "Flex r mortgage" "' 8 `" "Low debt" "' 9.5 `"  "{bf:By debt type}" "' 11 `" "Cash" "' 12 `" "Financial assets" "' 13 `" "No savings" "' 14.5 `"  "{bf:By savings}" "' 16 `" "Unemployed" "' 17 `" "Employed" "' 18 `" "Retirees" "' 19.5 `" "{bf:By employment}" "' 21 `" "18-30 years old" "' 22 `" "30-65 years old" "' 23 `" "65+ years old" "' 24.5 `"  "{bf:By age}" "' 26 `" "High income" "' 27 `" "Middle income" "' 28 `" "Low income" "' 29.5 `" "{bf:By income}" "', labsize(medsmall) noticks nogrid)   xtitle("" ) ytitle("")  xsize(10)  ysize(10) name(gr2, replace) yline(3.5 9.5 14.5 19.5 24.5) yline(1.5 2.5 5.5 6.5 7.5 11.5 12.5 16.5 17.5 21.5 22.5 26.5 27.5, lwidth(vthin) lcolor(gray%50))

			 resize, xsize(10cm) ysize(15cm)
	graph export $appendix_figures/figa6_1.png, width(2000) height(3000) as(png) replace
	
restore

}




*************************************************************
** Compute conditional shares and create the figure by age **
*************************************************************


{
preserve
global income dummy_distr_highincome dummy_distr_midincome dummy_distr_lowincome
global age dummy_distr_young dummy_distr_midage dummy_distr_old
global employment dummy_distr_unemp dummy_distr_emp dummy_distr_retire
global savings dummy_distr_cash dummy_distr_finassets dummy_distr_nosave
global debt dummy_distr_ccdebt dummy_distr_fixrate dummy_distr_flexrate dummy_distr_nodebt
global firms dummy_distr_smallfirms dummy_distr_bigfirms


* Compute and store conditional means and standard errors for each cause for respondents with age 18-29, 30-49, and 50-69.

global j=1

foreach var_selec of varlist $firms{
	sum `var_selec' if agegroup_agg==1
	scalar    firms_low_${j}=r(mean)*100 
	scalar se_firms_low_${j}=(r(sd)/sqrt(r(N)))*100
	global  j=$j +1
	sum `var_selec'  if agegroup_agg==2
	scalar    firms_${j}=r(mean)*100 
	scalar se_firms_${j}=(r(sd)/sqrt(r(N)))*100
	global  j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    firms_high_${j}=r(mean)*100 
	scalar se_firms_high_${j}=(r(sd)/sqrt(r(N)))*100

global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $debt{
	sum `var_selec' if agegroup_agg==1
	scalar    debt_low_${j}=r(mean)*100 
	scalar se_debt_low_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    debt_${j}=r(mean)*100 
	scalar se_debt_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    debt_high_${j}=r(mean)*100 
	scalar se_debt_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $savings {
	sum `var_selec' if agegroup_agg==1
	scalar    savings_low_${j}=r(mean)*100 
	scalar se_savings_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    savings_${j}=r(mean)*100 
	scalar se_savings_${j}=(r(sd)/sqrt(r(N)))*100
	global j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    savings_high_${j}=r(mean)*100 
	scalar se_savings_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2

}

global j=$j +5

foreach var_selec of varlist $employment{
	sum `var_selec' if agegroup_agg==1
	scalar    employment_low_${j}=r(mean)*100 
	scalar se_employment_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    employment_${j}=r(mean)*100 
	scalar se_employment_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if agegroup_agg==3
	scalar    employment_high_${j}=r(mean)*100 
	scalar se_employment_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $age{
		sum `var_selec' if agegroup_agg==1
	scalar    age_low_${j}=r(mean)*100 
	scalar se_age_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    age_${j}=r(mean)*100 
	scalar se_age_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==3
	scalar    age_high_${j}=r(mean)*100 
	scalar se_age_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}

global j=$j +5

foreach var_selec of varlist $income{
	sum `var_selec' if agegroup_agg==1
	scalar    income_low_${j}=r(mean)*100 
	scalar se_income_low_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
	sum `var_selec' if agegroup_agg==2
	scalar    income_${j}=r(mean)*100 
	scalar se_income_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +1
sum `var_selec' if agegroup_agg==3
	scalar    income_high_${j}=r(mean)*100 
	scalar se_income_high_${j}=(r(sd)/sqrt(r(N)))*100
global j=$j +2
}


clear
set obs 96
egen n = seq()


* Initialize variables to store the computed impacts and their confidence intervals for plotting

foreach var in firms firms_low firms_high debt debt_low debt_high savings savings_low savings_high employment employment_low employment_high age age_low age_high income income_low income_high {
gen `var' = . 
gen min_`var' = .
gen max_`var' = . 
}


* Replace the scalars in the corresponding variables

foreach x in 1 5 {
replace firms_low = firms_low_`x' if n == `x'
replace min_firms_low = firms_low_`x'  - 1.965 * se_firms_low_`x'  if n == `x'
replace max_firms_low = firms_low_`x'  + 1.965 * se_firms_low_`x'  if n == `x'
scalar up_`x'=firms_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 2 6 {
replace firms = firms_`x' if n == `x'
replace min_firms = firms_`x'  - 1.965 * se_firms_`x'  if n == `x'
replace max_firms = firms_`x'  + 1.965 * se_firms_`x'  if n == `x'
scalar up_`x'=firms_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 3 7 {
replace firms_high = firms_high_`x' if n == `x'
replace min_firms_high = firms_high_`x'  - 1.965 * se_firms_high_`x'  if n == `x'
replace max_firms_high = firms_high_`x'  + 1.965 * se_firms_high_`x'  if n == `x'
scalar up_`x'=firms_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


foreach x in 14 18 22 26 {
replace debt_low = debt_low_`x' if n == `x'
replace min_debt_low = debt_low_`x'  - 1.965 * se_debt_low_`x'  if n == `x'
replace max_debt_low = debt_low_`x'  + 1.965 * se_debt_low_`x'  if n == `x'
scalar up_`x'=debt_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 15 19 23 27 {
replace debt = debt_`x' if n == `x'
replace min_debt = debt_`x'  - 1.965 * se_debt_`x'  if n == `x'
replace max_debt = debt_`x'  + 1.965 * se_debt_`x'  if n == `x'
scalar up_`x'=debt_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 16 20 24 28 {
replace debt_high = debt_high_`x' if n == `x'
replace min_debt_high = debt_high_`x'  - 1.965 * se_debt_high_`x'  if n == `x'
replace max_debt_high = debt_high_`x'  + 1.965 * se_debt_high_`x'  if n == `x'
scalar up_`x'=debt_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 35 39 43 {
replace savings_low = savings_low_`x' if n == `x'
replace min_savings_low = savings_low_`x'  - 1.965 * se_savings_low_`x'  if n == `x'
replace max_savings_low = savings_low_`x'  + 1.965 * se_savings_low_`x'  if n == `x'
scalar up_`x'=savings_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 36 40 44 {
replace savings = savings_`x' if n == `x'
replace min_savings = savings_`x'  - 1.965 * se_savings_`x'  if n == `x'
replace max_savings = savings_`x'  + 1.965 * se_savings_`x'  if n == `x'
scalar up_`x'=savings_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 37 41 45 {
replace savings_high = savings_high_`x' if n == `x'
replace min_savings_high = savings_high_`x'  - 1.965 * se_savings_high_`x'  if n == `x'
replace max_savings_high = savings_high_`x'  + 1.965 * se_savings_high_`x'  if n == `x'
scalar up_`x'=savings_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 52 56 60 {
replace employment_low = employment_low_`x' if n == `x'
replace min_employment_low = employment_low_`x'  - 1.965 * se_employment_low_`x'  if n == `x'
replace max_employment_low = employment_low_`x'  + 1.965 * se_employment_low_`x'  if n == `x'
scalar up_`x'=employment_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 53 57 61 {
replace employment = employment_`x' if n == `x'
replace min_employment = employment_`x'  - 1.965 * se_employment_`x'  if n == `x'
replace max_employment = employment_`x'  + 1.965 * se_employment_`x'  if n == `x'
scalar up_`x'=employment_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 54 58 62 {
replace employment_high = employment_high_`x' if n == `x'
replace min_employment_high = employment_high_`x'  - 1.965 * se_employment_high_`x'  if n == `x'
replace max_employment_high = employment_high_`x'  + 1.965 * se_employment_high_`x'  if n == `x'
scalar up_`x'=employment_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 69 73 77 {
replace age_low = age_low_`x' if n == `x'
replace min_age_low = age_low_`x'  - 1.965 * se_age_low_`x'  if n == `x'
replace max_age_low = age_low_`x'  + 1.965 * se_age_low_`x'  if n == `x'
scalar up_`x'=age_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 70 74 78 {
replace age = age_`x' if n == `x'
replace min_age = age_`x'  - 1.965 * se_age_`x'  if n == `x'
replace max_age = age_`x'  + 1.965 * se_age_`x'  if n == `x'
scalar up_`x'=age_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 71 75 79 {
replace age_high = age_high_`x' if n == `x'
replace min_age_high = age_high_`x'  - 1.965 * se_age_high_`x'  if n == `x'
replace max_age_high = age_high_`x'  + 1.965 * se_age_high_`x'  if n == `x'
scalar up_`x'=age_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 86 90 94 {
replace income_low = income_low_`x' if n == `x'
replace min_income_low = income_low_`x'  - 1.965 * se_income_low_`x'  if n == `x'
replace max_income_low = income_low_`x'  + 1.965 * se_income_low_`x'  if n == `x'
scalar up_`x'=income_low_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}
	
foreach x in 87 91 95 {
replace income = income_`x' if n == `x'
replace min_income = income_`x'  - 1.965 * se_income_`x'  if n == `x'
replace max_income = income_`x'  + 1.965 * se_income_`x'  if n == `x'
scalar up_`x'=income_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}

foreach x in 88 92 96 {
replace income_high = income_high_`x' if n == `x'
replace min_income_high = income_high_`x'  - 1.965 * se_income_high_`x'  if n == `x'
replace max_income_high = income_high_`x'  + 1.965 * se_income_high_`x'  if n == `x'
scalar up_`x'=income_high_`x'
	scalar num_`x'= round(up_`x', 1)
	scalar pos1_`x'=up_`x'-15
	scalar pos2_`x'=up_`x'+25
	scalar pos3_`x'=up_`x'+9
}


* Create yvar for command scatter (to control vertical positioning)

gen temp = 0.5+n*0.25 if n<8
replace temp = 1.25 +n*0.25 if n<29 & temp==.
replace temp=2 +n*0.25 if n<46 & temp==.
replace temp=2.75 +n*0.25 if n<63 & temp==.
replace temp=3.5 + n*0.25 if n<80 & temp==.
replace temp=4.25 + n*0.25 if temp==.




* Set figure style and create the graph

grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"
graph twoway ( scatter temp firms_low , msymbol(T)  color(black)) (rcap min_firms_low max_firms_low temp,  lwidth( thin) horizontal color(black))   ( scatter temp firms , msymbol(S)  color(pink)) (rcap min_firms max_firms temp,  lwidth( thin) horizontal color(pink))   ( scatter temp firms_high , msymbol(a)  color(purple)  ) (rcap min_firms_high max_firms_high temp,  lwidth( thin) color(purple) horizontal)  ///
   ( scatter temp debt_low , msymbol(T)  color(black)  ) (rcap min_debt_low max_debt_low temp,  horizontal  color(black) lwidth( thin))  ( scatter temp debt , msymbol(S) color(pink)  ) (rcap min_debt max_debt temp,  horizontal  color(pink) lwidth( thin))   ( scatter temp debt_high , msymbol(a)   color(purple)  ) (rcap min_debt_high max_debt_high temp,  horizontal color(purple) lwidth( thin))    ///
    ( scatter temp savings_low , msymbol(T)  color(black)  ) (rcap min_savings_low max_savings_low temp, horizontal lwidth( thin)  color(black))  ( scatter temp savings ,msymbol(S)  color(pink)  ) (rcap min_savings max_savings temp, horizontal lwidth( thin)  color(pink))  ( scatter temp savings_high , msymbol(a)   color(purple)  ) (rcap min_savings_high max_savings_high temp,  lwidth( thin) horizontal color(purple)) ///
     ( scatter temp employment_low , msymbol(T)  color(black)  ) (rcap min_employment_low max_employment_low temp,  horizontal lwidth( thin) color(black))  ( scatter temp employment , msymbol(S)  color(pink)  ) (rcap min_employment max_employment temp,  horizontal lwidth( thin) color(pink))   ( scatter temp employment_high , msymbol(a)   color(purple)  ) (rcap min_employment_high max_employment_high temp,   lwidth( thin) horizontal color(purple)) ///
	  ( scatter temp age_low , msymbol(T)  color(black)  ) (rcap min_age_low max_age_low temp,  horizontal  color(black) lwidth( thin)) ( scatter temp age , msymbol(S) color(pink)  ) (rcap min_age max_age temp,  horizontal  color(pink) lwidth( thin))  ( scatter temp age_high , msymbol(a)   color(purple)  ) (rcap min_age_high max_age_high temp,  horizontal lwidth( thin) color(purple)) ///
	  ( scatter temp income_low , msymbol(T) color(black)  ) (rcap min_income_low max_income_low temp,  horizontal lwidth( thin)  color(black)) ( scatter temp income ,msymbol(S)  color(pink)  ) (rcap min_income max_income temp,  horizontal lwidth( thin)  color(pink)) ( scatter temp income_high , msymbol(a)  color(purple)  ) (rcap min_income_high max_income_high temp,  lwidth( thin) horizontal  color(purple)), ///
			 legend(order(1 3 5) lab(1 "{bf:18-29 years}") lab(3 "{bf:30-49 years}") lab(5 "{bf:50-69 years}")  size(standard) position(6) cols(2)  symysize(4) symxsize(4) rowgap(-2) colgap(0.6) just(left) symplacement(center)) xlabel(0(20)100, labsize(standard) ) ylabel(1 `" "Small companies" "'  2  `" "Large companies" "' 3.5 `" "{bf:By firm type}" "' 5 `" "Credit card debt" "' 6 `" "Fixed r mortgage" "' 7 `" "Flex r mortgage" "' 8 `" "Low debt" "' 9.5 `"  "{bf:By debt type}" "' 11 `" "Cash" "' 12 `" "Financial assets" "' 13 `" "No savings" "' 14.5 `"  "{bf:By savings}" "' 16 `" "Unemployed" "' 17 `" "Employed" "' 18 `" "Retirees" "' 19.5 `" "{bf:By employment}" "' 21 `" "18-30 years old" "' 22 `" "30-65 years old" "' 23 `" "65+ years old" "' 24.5 `"  "{bf:By age}" "' 26 `" "High income" "' 27 `" "Middle income" "' 28 `" "Low income" "' 29.5 `" "{bf:By income}" "', labsize(medsmall) noticks nogrid)   xtitle("" ) ytitle("")  xsize(10)  ysize(10) name(gr2, replace) yline(3.5 9.5 14.5 19.5 24.5) yline(1.5 2.5 5.5 6.5 7.5 11.5 12.5 16.5 17.5 21.5 22.5 26.5 27.5, lwidth(vthin) lcolor(gray%50))

	resize, xsize(10cm) ysize(15cm)		
	graph export $appendix_figures/figa6_2.png, width(2000) height(3000) as(png) replace

restore

}
