***************************************************************************
** This code generates Table A24, which reports the Romano-Wolf adjusted ** 
** p-value obtained with the rwolf2 package from Clarke(2021) for the    ** 
** estimates of Table A21.                                               **
***************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

****************************************************************************


*****************************************
** Rename variables for the regression **
*****************************************

* Perceived causes of inflation
rename cause_labor c_l
rename cause_fed c_fed
rename cause_politics c_p
rename cause_hh c_h
rename cause_firms c_f
rename cause_costs c_c

* Perceived consequences of inflation
rename cons_cognitive n_c
rename cons_polecon n_p
rename cons_efficiency n_e

* Perceived distributional impacts of inflation
rename low_inc_lost_more lilm

* Knowledge of inflation
rename correct_corr s_c

* Perceived trade-offs
rename index_tradeoffs_good i_tg
rename index_tradeoffs_policy i_tp

*Asset exposure
rename exposure_index ea

********************************************
** Prepare the globals for the regression **
********************************************

global demo_controls "women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed  marital_status_2 marital_status_3 marital_status_4 kids employment_group_2 employment_group_3 treatment conjoint_info   policy_first unemployment_first"
global regressors "c_l c_fed c_p c_h c_f c_c  n_c n_p n_e lilm s_c i_tg i_tp ea"

*********************************************************************
** Compute the Romano-Wolf adjusted p-values and create the table  **
*********************************************************************
{
preserve

* Rename dependent variables (policies to combat inflation)	
rename dummy_policy_transfer_highinc d_p_th
rename dummy_policy_corporatetaxes d_p_ct
rename dummy_policy_pricecaps d_p_pc
rename dummy_policy_wagecaps d_p_wc
rename dummy_policy_imports d_p_i
rename dummy_policy_antitrust d_p_anti

* Calculate the Romano-Wolf adjusted p-values (it takes 12 minutes, processor i7, RAM 16.0 GB)
rwolf2 (  reghdfe d_p_th $regressors $demo_controls, noabsorb vce(robust)) ///
	   ( reghdfe d_p_ct $regressors $demo_controls, noabsorb vce(robust)) ///
	   (  reghdfe d_p_pc $regressors $demo_controls, noabsorb vce(robust)) ///
	   (  reghdfe d_p_wc $regressors $demo_controls, noabsorb vce(robust)) ///
	   ( reghdfe d_p_i $regressors $demo_controls, noabsorb vce(robust)) ///
	   ( reghdfe d_p_anti $regressors $demo_controls, noabsorb vce(robust)) ///
	   , indepvars( $regressors ,  $regressors , $regressors , $regressors , $regressors , $regressors  ) reps(1000) seed(15112001)  

* Table name	   
global table_name "$appendix_tables/taba24"

* Store the values from the rwolf2 command in the correct order
local j 1
forvalues x=1(1)14{
	local rw_1_`x': display %5.3f e(RW)[`j',3]
	local ++j 
}

forvalues x=1(1)14{
	local rw_2_`x': display %5.3f e(RW)[`j',3]
	local ++j 
}

forvalues x=1(1)14{
	local rw_3_`x': display %5.3f e(RW)[`j',3]
	local ++j 
}

forvalues x=1(1)14{
	local rw_4_`x': display %5.3f e(RW)[`j',3]
	local ++j 
}

forvalues x=1(1)14{
	local rw_5_`x': display %5.3f e(RW)[`j',3]
	local ++j 
}

forvalues x=1(1)14{
	local rw_6_`x': display %5.3f e(RW)[`j',3]
	local ++j 
}

* Create the table
file open holder using $table_name.tex, write replace text
file write holder "\begin{tabular}{lcccccc} " _n
file write holder "&\multicolumn{6}{c}{\textbf{Policies to combat inflation:}} \\" _n
file write holder "& Tax high income to fund low income transfers & Increase corporate taxes & Price controls on essentials & Wage controls & Limit imports & Increase antitrust \\ \hline" _n
file write holder "& (1) & (2) & (3) & (4) & (5) & (6)  \\ \hline" _n
file write holder "\textbf{Perceived causes of inflation}\\" _n
file write holder "Changes in the labor market (e.g., wage-price spirals, labor shortages)&   `rw_1_1'    &    `rw_2_1'   &    `rw_3_1'   &   `rw_4_1'    &  `rw_5_1' &  `rw_6_1'    \\" _n
file write holder "Actions by the Federal Reserve (e.g, decrease interest rate, increase money supply)&      `rw_1_2'    &    `rw_2_2'   &    `rw_3_2'   &   `rw_4_2'    &  `rw_5_2' &  `rw_6_2'   \\" _n
file write holder "Politicians and political interests&    `rw_1_3'    &    `rw_2_3'   &    `rw_3_3'   &   `rw_4_3'    &  `rw_5_3'   &  `rw_6_3'   \\" _n
file write holder "Households spending more (e.g., because of optimism, because of increases in inflation expectations)&    `rw_1_4'    &    `rw_2_4'   &    `rw_3_4'   &   `rw_4_4'    &  `rw_5_4' &  `rw_6_4'  \\" _n
file write holder "Actions by firms and businesses (e.g., decrease in competition, increase prices to increase profits)&   `rw_1_5'    &    `rw_2_5'   &    `rw_3_5'   &   `rw_4_5'    &  `rw_5_5'   &  `rw_6_5'     \\" _n
file write holder "Increases in costs of production (e.g., supply chain disruptions, increases in oil prices)&    `rw_1_6'    &    `rw_2_6'   &    `rw_3_6'   &   `rw_4_6'    &  `rw_5_6'   &  `rw_6_6'  \\" _n
file write holder "\textbf{Perceived consequences of inflation}\\" _n
file write holder "Cognitive costs (uncertainty \& complex budgeting)&  `rw_1_7'    &    `rw_2_7'   &    `rw_3_7'   &   `rw_4_7'    &  `rw_5_7'  &  `rw_6_7' \\" _n
file write holder "Political \& social costs (trust in govt, social cohesion, inequality, lower natl. prestige)&  `rw_1_8'    &    `rw_2_8'   &    `rw_3_8'   &   `rw_4_8'    &  `rw_5_8'  &  `rw_6_8' \\" _n
file write holder "Efficiency costs (dollar value, GDP growth, resource misalloc., menu \& shoeleather costs, firms daily decisions)&  `rw_1_9'    &    `rw_2_9'   &    `rw_3_9'   &   `rw_4_9'    &  `rw_5_9'  &  `rw_6_9'    \\" _n
file write holder "\textbf{Perceived distributional impacts of inflation}\\ " _n
file write holder "Low income lost more than high income&   `rw_1_10'    &    `rw_2_10'   &    `rw_3_10'   &   `rw_4_10'    &  `rw_5_10'   &  `rw_6_10'  \\" _n
file write holder "\textbf{Knowledge of inflation}\\ " _n
file write holder "Number of correct answers to conditional correlations&   `rw_1_11'    &    `rw_2_11'   &    `rw_3_11'   &   `rw_4_11'    &  `rw_5_11'  &  `rw_6_11'  \\" _n
file write holder "\textbf{Perceived trade-offs}\\ " _n
file write holder "Inflation perceived as by-product of a good economy (e.g., more often in a boom)&   `rw_1_12'    &    `rw_2_12'   &    `rw_3_12'   &   `rw_4_12'    &  `rw_5_12'   &   `rw_6_12'      \\" _n
file write holder "Policy needs to reduce economic activity to fight inflation (e.g., reduce growth)&   `rw_1_13'    &    `rw_2_13'   &    `rw_3_13'   &   `rw_4_13'    &  `rw_5_13'   &   `rw_6_13'   \\" _n
file write holder "\textbf{Asset exposure}\\ " _n
file write holder "Net nominal position (in hundreds of thousands)&   `rw_1_14'    &    `rw_2_14'   &    `rw_3_14'   &   `rw_4_14'    &  `rw_5_14'   &  `rw_6_14'        \\" _n
file write holder "\hline" _n
file write holder " \end{tabular}" _n
file close holder

restore
}