***************************************************************************
** This code generates Figure 10,  which reports the coefficient of the  **
** corresponding news source for the outcome on the corresponding row,   **
** alongside 95% confidence intervals. Coefficients for the same outcome ** 
** are estimated jointly in a regression including demographic controls, **
** treatment indicators, order indicators, and controls for the news     **
** sources not listed in the figure.                                     **
***************************************************************************


clear all

use "$data/inflation_understanding_variables.dta", clear

***************************************************************************


*** set general style
grstyle init
grstyle set plain
set scheme modern
graph set window fontface "LMRoman10-Regular"


*******************************************
** Run regressions and create the figure **
*******************************************

*** LEFT FIGURE
{
preserve

* Initialize matrix to store regression results
matrix define R=J(42,5,.)

** Dependent variables
global demo_controls " women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed  marital_status_2 marital_status_3 marital_status_4 kids employment_group_2 employment_group_3 treatment conjoint_info policy_first unemployment_first"
global sources "news_cnn news_fox news_social_media news_npr news_nyt news_wsj news_msnbc    news_network news_localtv  news_amtalk   news_localpapers "


** Independent variables

* Preceived distributional impacts
global distributional "low_inc_lost_more"

*Perceived consequences
global consequences "cons_efficiency cons_polecon cons_cognitive"

*Preceived causes
global causes "cause_politics cause_firms cause_gvt"

local j 1
local k 0.75


* Run the regressions, extract and store coefficients and standard errors of interest. Compute and store confidence intervals of interest

foreach var of varlist $distributional{
	reg `var' $sources $demo_controls, r
	forvalues t=1(1)6{
		matrix R[`j',1]=e(b)[1,`t']
		matrix R[`j',2]=r(table)[2,`t']
		matrix R[`j',3]=R[`j',1]- invnormal(0.975)*R[`j',2]
		matrix R[`j',4]=R[`j',1]+ invnormal(0.975)*R[`j',2]
		matrix R[`j',5]=`k'
		local j = `j'+1
		local k = `k'+0.1
	}
	local k = `k'+0.4
}

local k = `k'+1
matlist R

foreach var of varlist $consequences{
	reg `var' $sources $demo_controls, r
	forvalues t=1(1)6{
		matrix R[`j',1]=e(b)[1,`t']
		matrix R[`j',2]=r(table)[2,`t']
		matrix R[`j',3]=R[`j',1]- invnormal(0.975)*R[`j',2]
		matrix R[`j',4]=R[`j',1]+ invnormal(0.975)*R[`j',2]
		matrix R[`j',5]=`k'
		local j = `j'+1
		local k = `k'+0.1
	}
	local k = `k'+0.4
}

local k = `k'+1
matlist R

foreach var of varlist $causes{
	reg `var' $sources $demo_controls, r
	forvalues t=1(1)6{
		matrix R[`j',1]=e(b)[1,`t']
		matrix R[`j',2]=r(table)[2,`t']
		matrix R[`j',3]=R[`j',1]- invnormal(0.975)*R[`j',2]
		matrix R[`j',4]=R[`j',1]+ invnormal(0.975)*R[`j',2]
		matrix R[`j',5]=`k'
		local j = `j'+1
		local k = `k'+0.1
	}
	local k = `k'+0.4
}

matlist R


* Convert matrix to dataset and assign meaningful variable names

clear
svmat R
rename R1 coef
rename R2 std_se
rename R3 lb
rename R4 ub
rename R5 spec


* Generate variable to distinguish results from different news sources

gen spec_string = strofreal(spec)
gen spec_long="cnn" if substr(spec_string,-3,.)==".75"
replace  spec_long="fox" if substr(spec_string,-3,.)==".85"
replace spec_long="fb" if substr(spec_string,-3,.)==".95"
replace spec_long="npr" if substr(spec_string,-3,.)==".05"
replace spec_long="nyt" if substr(spec_string,-3,.)==".15"
replace spec_long="wsj" if substr(spec_string,-3,.)==".25"


* Create the graph

graph twoway (scatter spec coef if spec_long=="cnn" , msymbol(D) color(black) ) (rcap lb ub spec if spec_long=="cnn",  color(black%60) horizontal) (scatter spec coef if spec_long=="fb" , msymbol(T) color(dknavy) ) (rcap lb ub spec if spec_long=="fb",  color(dknavy%60) horizontal) (scatter spec coef if spec_long=="fox" , color(red) msymbol(X) ) (rcap lb ub spec if spec_long=="fox",  color(red%60) horizontal) (scatter spec coef if spec_long=="npr" , msymbol(O) color(gold) ) (rcap lb ub spec if spec_long=="npr",  color(gold%60) horizontal) (scatter spec coef if spec_long=="nyt" , msymbol(V) color(gray) ) (rcap lb ub spec if spec_long=="nyt",  color(gray%60) horizontal) (scatter spec coef if spec_long=="wsj" , color(maroon) msymbol(A) ) (rcap lb ub spec if spec_long=="wsj",  color(maroon%60) horizontal) , ///
			legend(order(1 3 5 7 9 11) lab(1 "CNN") lab(3 "Social media") lab(5 "Fox News") lab(7 "NPR") lab(9 "NYT") lab(11 "WSJ") pos(6) col(3)) ylabel(0.75 " " 1 `" "Low income lost more" "than high income" "'  2  `" "{bf:Perceived distributional impacts}" "' 3 `" "Efficiency & economic costs" "' 4 `" "Political & social costs" "' 5 `" "Cognitive costs" "' 6  `" "{bf:Perceived consequences}" "' 7 `" "Politicians and political interests" "' 8 `" "Actions by firms and businesses" "' 9 `" "Government spending," "debt, and taxation" "' 10  `" "{bf:Perceived causes}" "'  , noticks nogrid labsize(medsmall)) yline(3.5 4.5 7.5 8.5, lcolor(gray%50) lwidth(vthin)) yline(2 6) ytitle(" ") xline(0, lpattern(straight)) xsize(7) ysize(7)
			
		resize, xsize(15cm) ysize(20cm)
		
		graph export $figures/fig11_1.png, width(2250) height(3000) as(png) replace
		
restore
}


*** RIGHT FIGURE
{
preserve

* Initialize matrix to store regression results
matrix define R=J(62,5,.)

** Dependent variables
global demo_controls " women agegroup_agg_2 agegroup_agg_3 independent republican college econ_studies incomegroup_agg_2 incomegroup_agg_3 race_black race_asian race_hisp race_mixed  marital_status_2 marital_status_3 marital_status_4 kids employment_group_2 employment_group_3 treatment conjoint_info policy_first unemployment_first"
global sources "news_cnn news_fox news_social_media news_npr news_nyt news_wsj news_msnbc    news_network news_localtv  news_amtalk   news_localpapers "


** Independent variables

*Policy views
global policy "dummy_policy_redib_minwage dummy_policy_corporatetaxes dummy_policy_pricecaps dummy_policy_debtreduce_highinc dummy_policy_decreaserate dummy_policy_increaserate"

*Perceived trade-offs
global tradeoffs "index_tradeoffs_policy index_tradeoffs_good"


* Run the regressions, extract and store coefficients and standard errors of interest. Compute and store confidence intervals of interest

local j 1
local k 0.75

foreach var of varlist $policy{
	reg `var' $sources $demo_controls, r
	forvalues t=1(1)6{
		matrix R[`j',1]=e(b)[1,`t']
		matrix R[`j',2]=r(table)[2,`t']
		matrix R[`j',3]=R[`j',1]- invnormal(0.975)*R[`j',2]
		matrix R[`j',4]=R[`j',1]+ invnormal(0.975)*R[`j',2]
		matrix R[`j',5]=`k'
		local j = `j'+1
		local k = `k'+0.1
	}
	local k = `k'+0.4
}

local k = `k'+1
matlist R

foreach var of varlist $tradeoffs{
	reg `var' $sources $demo_controls, r
	forvalues t=1(1)6{
		matrix R[`j',1]=e(b)[1,`t']
		matrix R[`j',2]=r(table)[2,`t']
		matrix R[`j',3]=R[`j',1]- invnormal(0.975)*R[`j',2]
		matrix R[`j',4]=R[`j',1]+ invnormal(0.975)*R[`j',2]
		matrix R[`j',5]=`k'
		local j = `j'+1
		local k = `k'+0.1
	}
	local k = `k'+0.4
}


* Convert matrix to dataset and assign meaningful variable names

clear
svmat R
rename R1 coef
rename R2 std_se
rename R3 lb
rename R4 ub
rename R5 spec


* Generate variable to distinguish results from different news sources

gen spec_string = strofreal(spec)
gen spec_long="cnn" if substr(spec_string,-3,.)==".75"
replace  spec_long="fox" if substr(spec_string,-3,.)==".85"
replace spec_long="fb" if substr(spec_string,-3,.)==".95"
replace spec_long="npr" if substr(spec_string,-3,.)==".05"
replace spec_long="nyt" if substr(spec_string,-3,.)==".15"
replace spec_long="wsj" if substr(spec_string,-3,.)==".25"

* Create the graph
graph twoway (scatter spec coef if spec_long=="cnn" , msymbol(D) color(black) ) (rcap lb ub spec if spec_long=="cnn",  color(black%60) horizontal) (scatter spec coef if spec_long=="fb" , msymbol(T) color(dknavy) ) (rcap lb ub spec if spec_long=="fb",  color(dknavy%60) horizontal) (scatter spec coef if spec_long=="fox" , color(red) msymbol(X) ) (rcap lb ub spec if spec_long=="fox",  color(red%60) horizontal) (scatter spec coef if spec_long=="npr" , msymbol(O) color(gold) ) (rcap lb ub spec if spec_long=="npr",  color(gold%60) horizontal) (scatter spec coef if spec_long=="nyt" , msymbol(V) color(gray) ) (rcap lb ub spec if spec_long=="nyt",  color(gray%60) horizontal) (scatter spec coef if spec_long=="wsj" , color(maroon) msymbol(A) ) (rcap lb ub spec if spec_long=="wsj",  color(maroon%60) horizontal) , ///
			legend(order(1 3 5 7 9 11) lab(1 "CNN") lab(3 "Social media") lab(5 "Fox News") lab(7 "NPR") lab(9 "NYT") lab(11 "WSJ") pos(6) col(3)) ylabel(0.75 " " 1 `" "Increase minimum wage" "'  2 `" "Increase corporate taxes" "' 3 `" "Freeze prices of essentials" "' 4 `" "Increase taxes on high" "income to reduce debt" "' 5 `" "Decrease interest rate" "' 6 `" "Increase interest rate" "' 7  `" "{bf:Policy views}" "' 8 `" "Policy needs to reduce economic" "activity to fight inflation" "' 9 `" "Inflation perceived as a by-product" "of a good economy" "'  10  `" "{bf:Perceived trade-offs}" "' , noticks nogrid labsize(medsmall)) yline(1.5 2.5 3.5 4.5 5.5 8.5, lcolor(gray%50) lwidth(vthin)) yline(7) ytitle(" ") xline(0, lpattern(straight)) xsize(7) ysize(7)
			
		resize, xsize(15cm) ysize(20cm)
		
			graph export $figures/fig11_2.png, width(2250) height(3000) as(png) replace
	
		
restore
}
